@@ -13,6 +13,12 @@
 #   under the License.
 #
 
+# @matbu backward compatibility for stable/train
+try:
+    from pathlib import PosixPath
+except ImportError:
+    from pathlib2 import PosixPath
+
 from validations_libs import constants
 
 VALIDATIONS_LIST = [{
@@ -247,7 +253,8 @@ FAKE_PLAYBOOK = [{'hosts': 'undercloud',
                                         'categories': ['os', 'storage'],
                                         'products': ['product1'],
                                         'name':
-                                        'Advanced Format 512e Support'}}}]
+                                        'Advanced Format 512e Support',
+                                        'path': '/tmp'}}}]
 
 FAKE_PLAYBOOK2 = [{'hosts': 'undercloud',
                    'roles': ['advanced_format_512e_support'],
@@ -273,14 +280,16 @@ FAKE_METADATA = {'id': 'foo',
                  'groups': ['prep', 'pre-deployment'],
                  'categories': ['os', 'storage'],
                  'products': ['product1'],
-                 'name': 'Advanced Format 512e Support'}
+                 'name': 'Advanced Format 512e Support',
+                 'path': '/tmp'}
 
 FORMATED_DATA = {'Description': 'foo',
                  'Groups': ['prep', 'pre-deployment'],
                  'Categories': ['os', 'storage'],
                  'Products': ['product1'],
                  'ID': 'foo',
-                 'Name': 'Advanced Format 512e Support'}
+                 'Name': 'Advanced Format 512e Support',
+                 'Path': '/tmp'}
 
 GROUP = {'no-op': [{'description': 'noop-foo'}],
          'pre': [{'description': 'pre-foo'}],
@@ -319,11 +328,20 @@ FAKE_FAILED_RUN = [{'Duration': '0:00:01.761',
 FAKE_VALIDATIONS_PATH = '/usr/share/ansible/validation-playbooks'
 
 DEFAULT_CONFIG = {'validation_dir': '/usr/share/ansible/validation-playbooks',
+                  'enable_community_validations': True,
                   'ansible_base_dir': '/usr/share/ansible/',
                   'output_log': 'output.log',
                   'history_limit': 15,
                   'fit_width': True}
 
+CONFIG_WITH_COMMUNITY_VAL_DISABLED = {
+    'validation_dir': '/usr/share/ansible/validation-playbooks',
+    'enable_community_validations': False,
+    'ansible_base_dir': '/usr/share/ansible/',
+    'output_log': 'output.log',
+    'history_limit': 15,
+    'fit_width': True}
+
 WRONG_HISTORY_CONFIG = {'default': {'history_limit': 0}}
 
 ANSIBLE_RUNNER_CONFIG = {'verbosity': 5,
@@ -335,6 +353,106 @@ ANSIBLE_ENVIRONNMENT_CONFIG = {'ANSIBLE_CALLBACK_WHITELIST':
                                'profile_tasks',
                                'ANSIBLE_STDOUT_CALLBACK': 'validation_stdout'}
 
+COVAL_SUBDIR = [PosixPath("/foo/bar/community-validations/roles"),
+                PosixPath("/foo/bar/community-validations/playbooks"),
+                PosixPath("/foo/bar/community-validations/library"),
+                PosixPath("/foo/bar/community-validations/lookup_plugins")]
+
+COVAL_MISSING_SUBDIR = [PosixPath("/foo/bar/community-validations/roles"),
+                        PosixPath("/foo/bar/community-validations/playbooks")]
+
+FAKE_COVAL_ITERDIR1 = iter(COVAL_SUBDIR)
+
+FAKE_COVAL_MISSING_SUBDIR_ITERDIR1 = iter(COVAL_MISSING_SUBDIR)
+
+FAKE_ROLES_ITERDIR1 = iter([PosixPath("/u/s/a/roles/role_1"),
+                            PosixPath("/u/s/a/roles/role_2"),
+                            PosixPath("/u/s/a/roles/role_3"),
+                            PosixPath("/u/s/a/roles/role_4"),
+                            PosixPath("/u/s/a/roles/role_5"),
+                            PosixPath("/u/s/a/roles/my_val")])
+
+FAKE_ROLES_ITERDIR2 = iter([PosixPath("/u/s/a/roles/role_1"),
+                            PosixPath("/u/s/a/roles/role_2"),
+                            PosixPath("/u/s/a/roles/role_3"),
+                            PosixPath("/u/s/a/roles/role_4"),
+                            PosixPath("/u/s/a/roles/role_5"),
+                            PosixPath("/u/s/a/roles/role_6")])
+
+FAKE_PLAYBOOKS_ITERDIR1 = iter([PosixPath("/u/s/a/plays/play_1.yaml"),
+                                PosixPath("/u/s/a/plays/play_2.yaml"),
+                                PosixPath("/u/s/a/plays/play_3.yaml"),
+                                PosixPath("/u/s/a/plays/play_4.yaml"),
+                                PosixPath("/u/s/a/plays/play_5.yaml"),
+                                PosixPath("/u/s/a/plays/my-val.yaml")])
+
+FAKE_PLAYBOOKS_ITERDIR2 = iter([PosixPath("/u/s/a/plays/play_1.yaml"),
+                                PosixPath("/u/s/a/plays/play_2.yaml"),
+                                PosixPath("/u/s/a/plays/play_3.yaml"),
+                                PosixPath("/u/s/a/plays/play_4.yaml"),
+                                PosixPath("/u/s/a/plays/play_5.yaml"),
+                                PosixPath("/u/s/a/plays/play_6.yaml")])
+
+FAKE_PLAYBOOK_TEMPLATE = \
+"""---
+# This playbook has been generated by the `validation init` CLI.
+#
+# As shown here in this template, the validation playbook requires three
+# top-level directive:
+#   ``hosts``, ``vars -> metadata`` and ``roles``.
+#
+# ``hosts``: specifies which nodes to run the validation on. The options can
+#            be ``all`` (run on all nodes), or you could use the hosts defined
+#            in the inventory.
+# ``vars``: this section serves for storing variables that are going to be
+#           available to the Ansible playbook. The validations API uses the
+#           ``metadata`` section to read each validation's name and description
+#           These values are then reported by the API.
+#
+# The validations can be grouped together by specyfying a ``groups`` metadata.
+# Groups function similar to tags and a validation can thus be part of many
+# groups. To get a full list of the groups available and their description,
+# please run the following command on your Ansible Controller host:
+#
+#    $ validation show group
+#
+# The validations can also be categorized by technical domain and acan belong to
+# one or multiple ``categories``. For example, if your validation checks some
+# networking related configuration, you may want to put ``networking`` as a
+# category.  Note that this section is open and you are free to categorize your
+# validations as you like.
+#
+# The ``products`` section refers to the product on which you would like to run
+# the validation. It's another way to categorized your community validations.
+# Note that, by default, ``community`` is set in the ``products`` section to
+# help you list your validations by filtering by products:
+#
+#    $ validation list --product community
+#
+- hosts: hostname
+  gather_facts: false
+  vars:
+    metadata:
+      name: Brief and general description of the validation
+      description: |
+        The complete description of this validation should be here
+# GROUPS:
+# Run ``validation show group`` to get the list of groups
+# :type group: `list`
+# If you don't want to add groups for your validation, just
+# set an empty list to the groups key
+      groups: []
+# CATEGORIES:
+# :type group: `list`
+# If you don't want to categorize your validation, just
+# set an empty list to the categories key
+      categories: []
+      products:
+        - community
+  roles:
+    - my_val
+"""
+
 
 def fake_ansible_runner_run_return(status='successful', rc=0):
     return status, rc
