@@ -21,6 +21,7 @@ except ImportError:
 from unittest import TestCase
 
 from ansible_runner import Runner
+from validations_libs import constants
 from validations_libs.ansible import Ansible
 from validations_libs.tests import fakes
 
@@ -175,6 +176,56 @@ class TestAnsible(TestCase):
                 '/tmp/foo/fact_cache'
             ))
 
+    def test_ansible_env_var_with_community_validations(self):
+        # AP No config file (use the default True)
+        env = self.run._ansible_env_var(
+                output_callback="", ssh_user="", workdir="", connection="",
+                gathering_policy="", module_path="", key="",
+                extra_env_variables="", ansible_timeout="",
+                callback_whitelist="", base_dir="", python_interpreter="",
+                env={}, validation_cfg_file=None)
+
+        assert("{}:".format(constants.COMMUNITY_LIBRARY_DIR) in env["ANSIBLE_LIBRARY"])
+        assert("{}:".format(constants.COMMUNITY_ROLES_DIR) in env["ANSIBLE_ROLES_PATH"])
+        assert("{}:".format(constants.COMMUNITY_LOOKUP_DIR) in env["ANSIBLE_LOOKUP_PLUGINS"])
+
+        # AP config file with no settting (use the default True)
+        env = self.run._ansible_env_var(
+                output_callback="", ssh_user="", workdir="", connection="",
+                gathering_policy="", module_path="", key="",
+                extra_env_variables="", ansible_timeout="",
+                callback_whitelist="", base_dir="", python_interpreter="",
+                env={}, validation_cfg_file={"default": {}})
+
+        assert("{}:".format(constants.COMMUNITY_LIBRARY_DIR) in env["ANSIBLE_LIBRARY"])
+        assert("{}:".format(constants.COMMUNITY_ROLES_DIR) in env["ANSIBLE_ROLES_PATH"])
+        assert("{}:".format(constants.COMMUNITY_LOOKUP_DIR) in env["ANSIBLE_LOOKUP_PLUGINS"])
+
+        # AP config file with settting True
+        env = self.run._ansible_env_var(
+                output_callback="", ssh_user="", workdir="", connection="",
+                gathering_policy="", module_path="", key="",
+                extra_env_variables="", ansible_timeout="",
+                callback_whitelist="", base_dir="", python_interpreter="",
+                env={}, validation_cfg_file={"default": {"enable_community_validations": True}})
+
+        assert("{}:".format(constants.COMMUNITY_LIBRARY_DIR) in env["ANSIBLE_LIBRARY"])
+        assert("{}:".format(constants.COMMUNITY_ROLES_DIR) in env["ANSIBLE_ROLES_PATH"])
+        assert("{}:".format(constants.COMMUNITY_LOOKUP_DIR) in env["ANSIBLE_LOOKUP_PLUGINS"])
+
+    def test_ansible_env_var_without_community_validations(self):
+        # AP config file with settting False
+        env = self.run._ansible_env_var(
+                output_callback="", ssh_user="", workdir="", connection="",
+                gathering_policy="", module_path="", key="",
+                extra_env_variables="", ansible_timeout="",
+                callback_whitelist="", base_dir="", python_interpreter="",
+                env={}, validation_cfg_file={"default": {"enable_community_validations": False}})
+
+        assert("{}:".format(constants.COMMUNITY_LIBRARY_DIR) not in env["ANSIBLE_LIBRARY"])
+        assert("{}:".format(constants.COMMUNITY_ROLES_DIR) not in env["ANSIBLE_ROLES_PATH"])
+        assert("{}:".format(constants.COMMUNITY_LOOKUP_DIR) not in env["ANSIBLE_LOOKUP_PLUGINS"])
+
     def test_get_extra_vars_dict(self):
         extra_vars = {
             'foo': 'bar'
