@@ -20,10 +20,16 @@ import logging
 import os
 import site
 import six
-import sys
+import subprocess
 import uuid
 
 from os.path import join
+# @matbu backward compatibility for stable/train
+try:
+    from pathlib import Path
+except ImportError:
+    from pathlib2 import Path
+
 from validations_libs import constants
 from validations_libs.group import Group
 from validations_libs.validation import Validation
@@ -36,6 +42,21 @@ def current_time():
     return '%sZ' % datetime.datetime.utcnow().isoformat()
 
 
+def community_validations_on(validation_config):
+    """Check for flag for community validations to be enabled
+    The default value is true
+
+    :param validation_config: A dictionary of configuration for Validation
+                              loaded from an validation.cfg file.
+    :type validation_config: ``dict``
+    :return: A boolean with the status of community validations flag
+    :rtype: `bool`
+    """
+    if not validation_config:
+        return True
+    return validation_config.get("default", {}).get("enable_community_validations", True)
+
+
 def create_log_dir(log_path=constants.VALIDATIONS_LOG_BASEDIR):
     """Check for presence of the selected validations log dir.
     Create the directory if needed, and use fallback if that
@@ -135,7 +156,8 @@ def create_artifacts_dir(log_path=constants.VALIDATIONS_LOG_BASEDIR,
 def parse_all_validations_on_disk(path,
                                   groups=None,
                                   categories=None,
-                                  products=None):
+                                  products=None,
+                                  validation_config=None):
     """Return a list of validations metadata which can be sorted by Groups, by
     Categories or by Products.
 
@@ -151,6 +173,10 @@ def parse_all_validations_on_disk(path,
     :param products: Products of validations
     :type products: `list`
 
+    :param validation_config: A dictionary of configuration for Validation
+                              loaded from an validation.cfg file.
+    :type validation_config: ``dict``
+
     :return: A list of validations metadata.
     :rtype: `list`
 
@@ -191,6 +217,9 @@ def parse_all_validations_on_disk(path,
 
     results = []
     validations_abspath = glob.glob("{path}/*.yaml".format(path=path))
+    if community_validations_on(validation_config):
+        validations_abspath.extend(glob.glob("{}/*.yaml".format(
+            constants.COMMUNITY_PLAYBOOKS_DIR)))
 
     LOG.debug(
         "Attempting to parse validations by:\n"
@@ -199,7 +228,6 @@ def parse_all_validations_on_disk(path,
         "  - products: {}\n"
         "from {}".format(groups, categories, products, validations_abspath)
     )
-
     for playbook in validations_abspath:
         val = Validation(playbook)
 
@@ -219,7 +247,8 @@ def get_validations_playbook(path,
                              validation_id=None,
                              groups=None,
                              categories=None,
-                             products=None):
+                             products=None,
+                             validation_config=None):
     """Get a list of validations playbooks paths either by their names,
     their groups, by their categories or by their products.
 
@@ -238,6 +267,10 @@ def get_validations_playbook(path,
     :param products: List of validation product
     :type products: `list`
 
+    :param validation_config: A dictionary of configuration for Validation
+                              loaded from an validation.cfg file.
+    :type validation_config: ``dict``
+
     :return: A list of absolute validations playbooks path
     :rtype: `list`
 
@@ -280,12 +313,15 @@ def get_validations_playbook(path,
         raise TypeError("The 'products' argument must be a List")
 
     pl = []
-    for f in os.listdir(path):
-        pl_path = join(path, f)
+    validations_abspath = glob.glob("{path}/*.yaml".format(path=path))
+    if community_validations_on(validation_config):
+        validations_abspath.extend(glob.glob("{}/*.yaml".format(
+                    constants.COMMUNITY_PLAYBOOKS_DIR)))
+    for pl_path in validations_abspath:
         if os.path.isfile(pl_path):
             if validation_id:
-                if os.path.splitext(f)[0] in validation_id or \
-                        os.path.basename(f) in validation_id:
+                if os.path.splitext(os.path.basename(pl_path))[0] in validation_id or \
+                        os.path.basename(pl_path) in validation_id:
                     pl.append(pl_path)
 
             val = Validation(pl_path)
@@ -376,7 +412,10 @@ def get_validations_details(validation):
     return {}
 
 
-def get_validations_data(validation, path=constants.ANSIBLE_VALIDATION_DIR):
+def get_validations_data(
+        validation,
+        path=constants.ANSIBLE_VALIDATION_DIR,
+        validation_config=None):
     """Return validation data with format:
 
     ID, Name, Description, Groups, Parameters
@@ -386,6 +425,9 @@ def get_validations_data(validation, path=constants.ANSIBLE_VALIDATION_DIR):
     :type validation: `string`
     :param path: The path to the validations directory
     :type path: `string`
+    :param validation_config: A dictionary of configuration for Validation
+                              loaded from an validation.cfg file.
+    :type validation_config: ``dict``
     :return: The validation data with the format
              (ID, Name, Description, Groups, Parameters)
     :rtype: `dict`
@@ -407,6 +449,9 @@ def get_validations_data(validation, path=constants.ANSIBLE_VALIDATION_DIR):
 
     data = {}
     val_path = "{}/{}.yaml".format(path, validation)
+    comm_path = ""
+    if community_validations_on(validation_config):
+        comm_path = "{}/{}.yaml".format(constants.COMMUNITY_PLAYBOOKS_DIR, validation)
 
     LOG.debug(
         "Obtaining information about validation {} from {}".format(
@@ -418,6 +463,11 @@ def get_validations_data(validation, path=constants.ANSIBLE_VALIDATION_DIR):
         val = Validation(val_path)
         data.update(val.get_formated_data)
         data.update({'Parameters': val.get_vars})
+    if not data and comm_path:
+        if os.path.exists(comm_path):
+            val = Validation(comm_path)
+            data.update(val.get_formated_data)
+            data.update({'Parameters': val.get_vars})
     return data
 
 
@@ -583,3 +633,120 @@ def find_config_file(config_file_name='validation.cfg'):
         if _check_path(current_path):
             return current_path
     return current_path
+
+
+def run_command_and_log(log, cmd, cwd=None,
+                        env=None, retcode_only=True):
+    """Run command and log output
+
+    :param log: Logger instance for logging
+    :type log: `Logger`
+
+    :param cmd: Command to run in list form
+    :type cmd: ``List``
+
+    :param cwd: Current working directory for execution
+    :type cmd: ``String``
+
+    :param env: Modified environment for command run
+    :type env: ``List``
+
+    :param retcode_only: Returns only retcode instead or proc object
+    :type retcdode_only: ``Boolean``
+    """
+    proc = subprocess.Popen(cmd, stdout=subprocess.PIPE,
+                            stderr=subprocess.STDOUT, shell=False,
+                            cwd=cwd, env=env)
+    if retcode_only:
+        while True:
+            try:
+                line = proc.stdout.readline()
+            except StopIteration:
+                break
+            if line != b'':
+                if isinstance(line, bytes):
+                    line = line.decode('utf-8')
+                log.debug(line.rstrip())
+            else:
+                break
+        proc.stdout.close()
+        return proc.wait()
+    return proc
+
+
+def check_community_validations_dir(
+        basedir=constants.COMMUNITY_VALIDATIONS_BASEDIR,
+        subdirs=constants.COMMUNITY_VALIDATIONS_SUBDIR):
+    """Check presence of the community validations directory structure
+
+    The community validations are stored and located in:
+
+    .. code-block:: console
+
+        /home/<username>/community-validations
+        ├── library
+        ├── lookup_plugins
+        ├── playbooks
+        └── roles
+
+    This function checks for the presence of the community-validations directory
+    in the $HOME of the user running the validation CLI. If the primary
+    directory doesn't exist, this function will create it and will check if the
+    four subdirectories are present and will create them otherwise.
+
+    :param basedir: Absolute path of the community validations
+    :type basedir: ``pathlib.PosixPath``
+
+    :param subdirs: List of Absolute path of the community validations subdirs
+    :type subdirs: ``list`` of ``pathlib.PosixPath``
+
+    :rtype: ``NoneType``
+    """
+    recreated_comval_dir = []
+
+    def create_subdir(subdir):
+        for _dir in subdir:
+            LOG.debug(
+                "Missing {} directory in {}:"
+                .format(Path(_dir).name, basedir)
+            )
+            Path.mkdir(_dir)
+            recreated_comval_dir.append(_dir)
+            LOG.debug(
+                "└── {} directory created successfully..."
+                .format(_dir)
+            )
+
+    if Path(basedir).exists and Path(basedir).is_dir():
+        _subdirectories = [x for x in basedir.iterdir() if x.is_dir()]
+        missing_dirs = [
+            _dir for _dir in subdirs
+            if _dir not in _subdirectories
+        ]
+
+        create_subdir(missing_dirs)
+    else:
+        LOG.debug(
+            "The community validations {} directory is not present:"
+            .format(basedir)
+        )
+        Path.mkdir(basedir)
+        recreated_comval_dir.append(basedir)
+        LOG.debug("└── {} directory created...".format(basedir))
+        create_subdir(subdirs)
+
+    LOG.debug(
+        (
+            "The {} directory and its required subtree are present "
+            "and correct:\n"
+            "{}/\n"
+            "├── library            OK\n"
+            "├── lookup_plugins     OK\n"
+            "├── playbooks          OK\n"
+            "└── roles              OK\n"
+            .format(
+                basedir,
+                basedir)
+        )
+    )
+    return recreated_comval_dir
